import 'dart:convert';

import 'package:flutter/material.dart';

import '../../../models/topartists.dart';
import '../../../network/scrobbles_api.dart';
import '../../../ui/widgets/error.dart';
import '../../../ui/widgets/main_screen/topartists_content.dart';

class ChartTopArtistsCard extends StatelessWidget {
  const ChartTopArtistsCard({super.key});

  @override
  Widget build(BuildContext context) {
    final int daysCount = 14;
    late Future<TopArtistsData> futureTimeline = ScrobblesApi.fetchTopArtists(daysCount);

    return FutureBuilder<TopArtistsData>(
      future: futureTimeline,
      builder: (context, snapshot) {
        if (snapshot.hasError) {
          return ShowErrorWidget(message: '${snapshot.error}');
        }

        return Card(
          elevation: 2,
          shadowColor: Theme.of(context).colorScheme.shadow,
          color: Theme.of(context).colorScheme.surface,
          shape: const RoundedRectangleBorder(
            borderRadius: BorderRadius.all(
              Radius.circular(8),
            ),
          ),
          child: Padding(
            padding: const EdgeInsets.all(8.0),
            child: ChartTopArtistsCardContent(
              daysCount: daysCount,
              chartData: snapshot.hasData
                  ? TopArtistsData.fromJson(jsonDecode(snapshot.data.toString()))
                  : TopArtistsData.createEmpty(),
              isLoading: !snapshot.hasData,
            ),
          ),
        );
      },
    );
  }
}
